%bcond_with reconf

%define major 2.52
%define fix 0

Name: glib2
Version: %{major}.%{fix}
Release: 5
License: GPL-2.0-or-later
Summary: GNOME low level libraries
Url: https://wiki.gnome.org/Projects/GLib

Source0: https://download.gnome.org/sources/glib/%{major}/glib-%{version}.tar.xz

Patch0: glib2-no-at-functions.patch

BuildRequires: python3
BuildRequires: libintl-devel
BuildRequires: gettext-tools
BuildRequires: gettext-runtime
BuildRequires: libiconv-devel
BuildRequires: libffi-devel
BuildRequires: pcre-devel
BuildRequires: zlib-devel
BuildRequires: pkg-config


%description
GLib provides the core application building blocks for libraries and
applications written in C. It provides the core object system used in GNOME, the
main loop implementation, and a large set of utility functions for strings and
common data structures.

%package devel
Summary: Glib2 development files
Requires: libgio-2_0-0 = %{version}-%{release}
Requires: libglib-2_0-0 = %{version}-%{release}
Requires: libgmodule-2_0-0 = %{version}-%{release}
Requires: libgobject-2_0-0 = %{version}-%{release}
Requires: libgthread-2_0-0 = %{version}-%{release}

# glib has a header-only wrapper around libintl/gettext
# so its pkgconfig file requires it to be installed just
# in case it is used
Requires: libintl-devel

%description devel
Files needed to build Glib2 applications

%package -n libgio-2_0-0
Summary: GNOME low level libraries

%description -n libgio-2_0-0
GNOME low level libraries

%package -n libglib-2_0-0
Summary: GNOME low level libraries

%description -n libglib-2_0-0
GNOME low level libraries

%package -n libgmodule-2_0-0
Summary: GNOME low level libraries

%description -n libgmodule-2_0-0
GNOME low level libraries

%package -n libgobject-2_0-0
Summary: GNOME low level libraries

%description -n libgobject-2_0-0
GNOME low level libraries

%package -n libgthread-2_0-0
Summary: GNOME low level libraries

%description -n libgthread-2_0-0
GNOME low level libraries

%prep
%setup -q -n glib-%{version}

%patch0 -p1

%build

%if %{with reconf}
autoreconf -fi
%else
%define _host powerpc-ibm-aix6
%endif

%configure \
  CPPFLAGS="-I%{_includedir}/libiconv" \
  LDFLAGS="-Wl,-brtl -Wl,-blibpath:%{_libdir}:/QOpenSys/usr/lib" \
  --with-aix-soname=svr4 \
  --with-python=%{_bindir}/python3 \
  --with-libiconv=gnu \
  --with-pcre=system \
  --disable-selinux \
  --disable-fam \
  --disable-xattr \
  --disable-libelf \
  --disable-gtk-doc-html \
  --disable-dtrace \
  --disable-systemtap \
  --disable-static \
  # end

%make_build


%install

%make_install

rm %{buildroot}%{_libdir}/charset.alias || :

rm -r %{buildroot}%{_datadir}/glib-2.0/codegen/__pycache__

rm -r %{buildroot}%{_datadir}/glib-2.0/valgrind

# Get rid of *.private sections since we don't support static linking
perl -n -i -e 'print unless m/[.]private/' %{buildroot}%{_libdir}/pkgconfig/*.pc

%files -n libgio-2_0-0
%defattr(-, qsys, *none)

%{_libdir}/libgio-2.0.so.0

%files -n libglib-2_0-0
%defattr(-, qsys, *none)

%{_libdir}/libglib-2.0.so.0

%files -n libgmodule-2_0-0
%defattr(-, qsys, *none)

%{_libdir}/libgmodule-2.0.so.0

%files -n libgobject-2_0-0
%defattr(-, qsys, *none)

%{_libdir}/libgobject-2.0.so.0

%files -n libgthread-2_0-0
%defattr(-, qsys, *none)

%{_libdir}/libgthread-2.0.so.0

%files
%defattr(-, qsys, *none)

%{_bindir}/gapplication
%{_bindir}/gdbus
%{_bindir}/gdbus-codegen
%{_bindir}/gio
%{_bindir}/gio-querymodules
%{_bindir}/glib-compile-resources
%{_bindir}/glib-compile-schemas
%{_bindir}/glib-genmarshal
%{_bindir}/glib-gettextize
%{_bindir}/glib-mkenums
%{_bindir}/gobject-query
%{_bindir}/gresource
%{_bindir}/gsettings
%{_bindir}/gtester
%{_bindir}/gtester-report

%dir %{_libdir}/gio/modules

%{_datadir}/bash-completion/completions/gapplication
%{_datadir}/bash-completion/completions/gdbus
%{_datadir}/bash-completion/completions/gresource
%{_datadir}/bash-completion/completions/gsettings

%{_datadir}/gettext/its/gschema.its
%{_datadir}/gettext/its/gschema.loc

%{_datadir}/glib-2.0/codegen


%{_datadir}/glib-2.0/gettext/po/Makefile.in.in
%{_datadir}/glib-2.0/schemas/gschema.dtd

%{_datadir}/gtk-doc/html/*

%{_datadir}/locale/af/LC_MESSAGES/glib20.mo
%{_datadir}/locale/am/LC_MESSAGES/glib20.mo
%{_datadir}/locale/an/LC_MESSAGES/glib20.mo
%{_datadir}/locale/ar/LC_MESSAGES/glib20.mo
%{_datadir}/locale/as/LC_MESSAGES/glib20.mo
%{_datadir}/locale/ast/LC_MESSAGES/glib20.mo
%{_datadir}/locale/az/LC_MESSAGES/glib20.mo
%{_datadir}/locale/be/LC_MESSAGES/glib20.mo
%{_datadir}/locale/be@latin/LC_MESSAGES/glib20.mo
%{_datadir}/locale/bg/LC_MESSAGES/glib20.mo
%{_datadir}/locale/bn/LC_MESSAGES/glib20.mo
%{_datadir}/locale/bn_IN/LC_MESSAGES/glib20.mo
%{_datadir}/locale/bs/LC_MESSAGES/glib20.mo
%{_datadir}/locale/ca/LC_MESSAGES/glib20.mo
%{_datadir}/locale/ca@valencia/LC_MESSAGES/glib20.mo
%{_datadir}/locale/cs/LC_MESSAGES/glib20.mo
%{_datadir}/locale/cy/LC_MESSAGES/glib20.mo
%{_datadir}/locale/da/LC_MESSAGES/glib20.mo
%{_datadir}/locale/de/LC_MESSAGES/glib20.mo
%{_datadir}/locale/dz/LC_MESSAGES/glib20.mo
%{_datadir}/locale/el/LC_MESSAGES/glib20.mo
%{_datadir}/locale/en@shaw/LC_MESSAGES/glib20.mo
%{_datadir}/locale/en_CA/LC_MESSAGES/glib20.mo
%{_datadir}/locale/en_GB/LC_MESSAGES/glib20.mo
%{_datadir}/locale/eo/LC_MESSAGES/glib20.mo
%{_datadir}/locale/es/LC_MESSAGES/glib20.mo
%{_datadir}/locale/et/LC_MESSAGES/glib20.mo
%{_datadir}/locale/eu/LC_MESSAGES/glib20.mo
%{_datadir}/locale/fa/LC_MESSAGES/glib20.mo
%{_datadir}/locale/fi/LC_MESSAGES/glib20.mo
%{_datadir}/locale/fr/LC_MESSAGES/glib20.mo
%{_datadir}/locale/fur/LC_MESSAGES/glib20.mo
%{_datadir}/locale/ga/LC_MESSAGES/glib20.mo
%{_datadir}/locale/gd/LC_MESSAGES/glib20.mo
%{_datadir}/locale/gl/LC_MESSAGES/glib20.mo
%{_datadir}/locale/gu/LC_MESSAGES/glib20.mo
%{_datadir}/locale/he/LC_MESSAGES/glib20.mo
%{_datadir}/locale/hi/LC_MESSAGES/glib20.mo
%{_datadir}/locale/hr/LC_MESSAGES/glib20.mo
%{_datadir}/locale/hu/LC_MESSAGES/glib20.mo
%{_datadir}/locale/hy/LC_MESSAGES/glib20.mo
%{_datadir}/locale/id/LC_MESSAGES/glib20.mo
%{_datadir}/locale/is/LC_MESSAGES/glib20.mo
%{_datadir}/locale/it/LC_MESSAGES/glib20.mo
%{_datadir}/locale/ja/LC_MESSAGES/glib20.mo
%{_datadir}/locale/ka/LC_MESSAGES/glib20.mo
%{_datadir}/locale/kk/LC_MESSAGES/glib20.mo
%{_datadir}/locale/kn/LC_MESSAGES/glib20.mo
%{_datadir}/locale/ko/LC_MESSAGES/glib20.mo
%{_datadir}/locale/ku/LC_MESSAGES/glib20.mo
%{_datadir}/locale/lt/LC_MESSAGES/glib20.mo
%{_datadir}/locale/lv/LC_MESSAGES/glib20.mo
%{_datadir}/locale/mai/LC_MESSAGES/glib20.mo
%{_datadir}/locale/mg/LC_MESSAGES/glib20.mo
%{_datadir}/locale/mk/LC_MESSAGES/glib20.mo
%{_datadir}/locale/ml/LC_MESSAGES/glib20.mo
%{_datadir}/locale/mn/LC_MESSAGES/glib20.mo
%{_datadir}/locale/mr/LC_MESSAGES/glib20.mo
%{_datadir}/locale/ms/LC_MESSAGES/glib20.mo
%{_datadir}/locale/nb/LC_MESSAGES/glib20.mo
%{_datadir}/locale/nds/LC_MESSAGES/glib20.mo
%{_datadir}/locale/ne/LC_MESSAGES/glib20.mo
%{_datadir}/locale/nl/LC_MESSAGES/glib20.mo
%{_datadir}/locale/nn/LC_MESSAGES/glib20.mo
%{_datadir}/locale/oc/LC_MESSAGES/glib20.mo
%{_datadir}/locale/or/LC_MESSAGES/glib20.mo
%{_datadir}/locale/pa/LC_MESSAGES/glib20.mo
%{_datadir}/locale/pl/LC_MESSAGES/glib20.mo
%{_datadir}/locale/ps/LC_MESSAGES/glib20.mo
%{_datadir}/locale/pt/LC_MESSAGES/glib20.mo
%{_datadir}/locale/pt_BR/LC_MESSAGES/glib20.mo
%{_datadir}/locale/ro/LC_MESSAGES/glib20.mo
%{_datadir}/locale/ru/LC_MESSAGES/glib20.mo
%{_datadir}/locale/rw/LC_MESSAGES/glib20.mo
%{_datadir}/locale/si/LC_MESSAGES/glib20.mo
%{_datadir}/locale/sk/LC_MESSAGES/glib20.mo
%{_datadir}/locale/sl/LC_MESSAGES/glib20.mo
%{_datadir}/locale/sq/LC_MESSAGES/glib20.mo
%{_datadir}/locale/sr/LC_MESSAGES/glib20.mo
%{_datadir}/locale/sr@ije/LC_MESSAGES/glib20.mo
%{_datadir}/locale/sr@latin/LC_MESSAGES/glib20.mo
%{_datadir}/locale/sv/LC_MESSAGES/glib20.mo
%{_datadir}/locale/ta/LC_MESSAGES/glib20.mo
%{_datadir}/locale/te/LC_MESSAGES/glib20.mo
%{_datadir}/locale/tg/LC_MESSAGES/glib20.mo
%{_datadir}/locale/th/LC_MESSAGES/glib20.mo
%{_datadir}/locale/tl/LC_MESSAGES/glib20.mo
%{_datadir}/locale/tr/LC_MESSAGES/glib20.mo
%{_datadir}/locale/tt/LC_MESSAGES/glib20.mo
%{_datadir}/locale/ug/LC_MESSAGES/glib20.mo
%{_datadir}/locale/uk/LC_MESSAGES/glib20.mo
%{_datadir}/locale/vi/LC_MESSAGES/glib20.mo
%{_datadir}/locale/wa/LC_MESSAGES/glib20.mo
%{_datadir}/locale/xh/LC_MESSAGES/glib20.mo
%{_datadir}/locale/yi/LC_MESSAGES/glib20.mo
%{_datadir}/locale/zh_CN/LC_MESSAGES/glib20.mo
%{_datadir}/locale/zh_HK/LC_MESSAGES/glib20.mo
%{_datadir}/locale/zh_TW/LC_MESSAGES/glib20.mo


%files devel
%defattr(-, qsys, *none)

%{_includedir}/gio-unix-2.0
%{_includedir}/glib-2.0


%{_libdir}/glib-2.0/include/glibconfig.h

%{_libdir}/libgio-2.0.so
%{_libdir}/libglib-2.0.so
%{_libdir}/libgmodule-2.0.so
%{_libdir}/libgobject-2.0.so
%{_libdir}/libgthread-2.0.so

%{_libdir}/pkgconfig/gio-2.0.pc
%{_libdir}/pkgconfig/gio-unix-2.0.pc
%{_libdir}/pkgconfig/glib-2.0.pc
%{_libdir}/pkgconfig/gmodule-2.0.pc
%{_libdir}/pkgconfig/gmodule-export-2.0.pc
%{_libdir}/pkgconfig/gmodule-no-export-2.0.pc
%{_libdir}/pkgconfig/gobject-2.0.pc
%{_libdir}/pkgconfig/gthread-2.0.pc

%{_datadir}/aclocal/glib-2.0.m4
%{_datadir}/aclocal/glib-gettext.m4
%{_datadir}/aclocal/gsettings.m4

%{_datadir}/glib-2.0/gdb

%{_datadir}/gdb/auto-load%{_libdir}/libglib-2.0.so.0.5200.0-gdb.py
%{_datadir}/gdb/auto-load%{_libdir}/libgobject-2.0.so.0.5200.0-gdb.py


%changelog
* Thu Nov 4 2021 Jason Hansen <stymie@us.ibm.com> - 2.52.0
- Intra-package Requires need version and release

* Wed Nov 18 2020 Abdirahim Musse <abdirahim.musse@ibm.com> - 2.52.0
- Use brp-rm-libtool-files

* Thu Nov 21 2019 Kevin Adler <kadler@us.ibm.com> - 2.52.0
- Disable half-implemented *at APIs, fixing IBM i 7.2 build

* Wed Nov 20 2019 Kevin Adler <kadler@us.ibm.com> - 2.52.0
- Enhance reconf handling
- Use SPDX license identifier

* Wed Aug 08 2018 - Kevin Adler <kadler@us.ibm.com>
- Fix glib2-devel dependencies

* Fri Mar 30 2018 - Kevin Adler <kadler@us.ibm.com>
- Fix unpackaged file errors in glib2

* Wed Mar 28 2018 - Kevin Adler <kadler@us.ibm.com>
- Ensure glib2-devel requires the glib2 libraries

* Sat Mar 03 2018 - Kevin Adler <kadler@us.ibm.com>
- Add build dependencies to glib2 and cleanup spec

* Wed Dec 20 2017 - Kevin Adler <kadler@us.ibm.com>
- Ship libraries in gettext subpackages

* Wed Dec 20 2017 - Kevin Adler <kadler@us.ibm.com>
- Remove 64-bit GCC script workarounds

* Tue Nov 21 2017 - Kevin Adler <kadler@us.ibm.com>
- Rename glib package to glib2
